﻿require 'xmlsimple'

# This class is used to parse the configuration file and supply information regarding it
class Configuration

	# Constructor, parses the config.xml file
	def initialize
		@config = XmlSimple.xml_in('config.xml')
		@regexpArray = @config['dateMask'].dup()
		@dateMaskArray = @config['dateMask'].dup()
		i = 0
		while i < @regexpArray.length()
			# creating regular epressions matching the given date strings
			@regexpArray[i] = @regexpArray[i].gsub(/YYYY/,'[\d]{4}')
			@regexpArray[i] = @regexpArray[i].gsub(/YY/,'[\d]{2}')
			@regexpArray[i] = @regexpArray[i].gsub(/MM/,'[\d]{2}')
			@regexpArray[i] = @regexpArray[i].gsub(/DD/,'[\d]{2}')
			@regexpArray[i] = @regexpArray[i].gsub(/HH/,'[\d]{2}')
			@regexpArray[i] = @regexpArray[i].gsub(/MI/,'[\d]{2}')
			@regexpArray[i] = @regexpArray[i].gsub(/SS/,'[\d]{2}')
			# creating date masks compatible with the Time module's strftime method
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/YYYY/,'%Y')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/YY/,'%y')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/MM/,'%m')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/DD/,'%d')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/HH/,'%H')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/MI/,'%M')
			@dateMaskArray[i] = @dateMaskArray[i].gsub(/SS/,'%S')
			i += 1
		end
	end
	
	# returns the value of the fileNameGlob paramter
	def glob
		return @config['fileNameGlob'][0]
	end
	
	# returns the value of the sourceDirectory paramter
	def sourceDir
		return @config['sourceDirectory'][0]
	end
	
	# returns the value of the epoch paramter
	def epoch
		return @config['epoch'][0]
	end
	
	# returns the array of regular expressions
	def dateRegexps
		return @regexpArray
	end
	
	# returns the array of date masks suited for the strftime method
	def dateMasks
		return @dateMaskArray
	end
	
end

print "Parsing configuration file..."
$config = Configuration.new()
puts "Done!"

print "Scanning for files under '#{File.expand_path($config.sourceDir)}' using the glob '#{$config.glob}'..."
Dir.chdir(File.expand_path($config.sourceDir))
$fileNames = Dir.glob("**/" +$config.glob) #recursive search using the glob
puts "Done!"

$fileNames.each do |fileName|
	puts "Updating file '#{File.expand_path(fileName)}'."

	fileContent = File.read(fileName)
	regexpArray = $config.dateRegexps
	dateMaskArray = $config.dateMasks
	epoch = Time.at(Integer($config.epoch))
	i = 0

	while i < regexpArray.length()
		fileContent = fileContent.gsub(/#{regexpArray[i]}/, epoch.strftime(dateMaskArray[i]))
		i += 1
	end
	
	File.open(fileName, "w") {|file| file.print fileContent}
end